==> reakit-0.14.5.tgz: package/es/Group.js <==
import { prop, ifProp, withProp } from 'styled-tools';
import styled, { css } from './styled.js';
import as from './as.js';
import Box from './Box.js';
import PropTypes__default from 'prop-types';
import Base from './Base.js';
import 'styled-components';
import './chunk-fb907809.js';
import '@emotion/is-prop-valid';
import 'react';
import './chunk-254efadd.js';
import './chunk-a7ce379e.js';

var GroupItem = styled(Box).withConfig({
  displayName: "GroupItem"
})(["", ";"], prop("theme.GroupItem"));
var GroupItem$1 = as("div")(GroupItem);

var verticalAt = function verticalAt(pass, fail) {
  return ifProp("verticalAt", css(["@media (min-width:", "px){", ";}@media (max-width:", "px){", ";}"], withProp("verticalAt", function (x) {
    return x + 1;
  }), fail, prop("verticalAt"), pass), fail);
};

var Group = styled(Base).withConfig({
  displayName: "Group"
})(["display:flex;flex-direction:", ";", ";> *,> * ", "{min-height:2.5em;height:auto;}> *:not(:first-child):not(:last-child),> *:not(:first-child):not(:last-child) ", "{border-radius:0;", ";}> *:first-child,> *:first-child ", "{border-bottom-right-radius:0;", ";}> *:last-child,> *:last-child ", "{border-top-left-radius:0;", ";}", ";"], ifProp("vertical", "column", "row"), verticalAt("flex-direction: column"), GroupItem$1, GroupItem$1, verticalAt(css(["border-top-width:0;"]), css(["border-", "-width:0;"], ifProp("vertical", "top", "left"))), GroupItem$1, verticalAt(css(["border-bottom-left-radius:0;"]), css(["border-", "-radius:0;"], ifProp("vertical", "bottom-left", "top-right"))), GroupItem$1, verticalAt(css(["border-top-width:0;border-top-right-radius:0;"]), css(["border-", "-width:0;border-", "-radius:0;"], ifProp("vertical", "top", "left"), ifProp("vertical", "top-right", "bottom-left"))), prop("theme.Group"));
Group.propTypes = {
  vertical: PropTypes__default.bool,
  verticalAt: PropTypes__default.number
};
Group.defaultProps = {
  role: "group"
};
var Group$1 = as("div")(Group);

Group$1.Item = GroupItem$1;

export default Group$1;

==> reakit-0.14.6.tgz: package/es/Group.js <==
import { prop, ifProp, withProp } from 'styled-tools';
import styled, { css } from './styled.js';
import as from './as.js';
import Box from './Box.js';
import PropTypes__default from 'prop-types';
import Base from './Base.js';
import 'styled-components';
import './chunk-fb907809.js';
import '@emotion/is-prop-valid';
import 'react';
import 'hoist-non-react-statics';
import './chunk-254efadd.js';
import './chunk-a7ce379e.js';

var GroupItem = styled(Box).withConfig({
  displayName: "GroupItem",
  componentId: "kbprqg-0"
})(["", ";"], prop("theme.GroupItem"));
var GroupItem$1 = as("div")(GroupItem);

var verticalAt = function verticalAt(pass, fail) {
  return ifProp("verticalAt", css(["@media (min-width:", "px){", ";}@media (max-width:", "px){", ";}"], withProp("verticalAt", function (x) {
    return x + 1;
  }), fail, prop("verticalAt"), pass), fail);
};

var Group = styled(Base).withConfig({
  displayName: "Group",
  componentId: "ope6r0-0"
})(["display:flex;flex-direction:", ";", ";> *,> * ", "{min-height:2.5em;height:auto;}> *:not(:first-child):not(:last-child),> *:not(:first-child):not(:last-child) ", "{border-radius:0;", ";}> *:first-child,> *:first-child ", "{border-bottom-right-radius:0;", ";}> *:last-child,> *:last-child ", "{border-top-left-radius:0;", ";}", ";"], ifProp("vertical", "column", "row"), verticalAt("flex-direction: column"), GroupItem$1, GroupItem$1, verticalAt(css(["border-top-width:0;"]), css(["border-", "-width:0;"], ifProp("vertical", "top", "left"))), GroupItem$1, verticalAt(css(["border-bottom-left-radius:0;"]), css(["border-", "-radius:0;"], ifProp("vertical", "bottom-left", "top-right"))), GroupItem$1, verticalAt(css(["border-top-width:0;border-top-right-radius:0;"]), css(["border-", "-width:0;border-", "-radius:0;"], ifProp("vertical", "top", "left"), ifProp("vertical", "top-right", "bottom-left"))), prop("theme.Group"));
Group.propTypes = {
  vertical: PropTypes__default.bool,
  verticalAt: PropTypes__default.number
};
Group.defaultProps = {
  role: "group"
};
var Group$1 = as("div")(Group);

Group$1.Item = GroupItem$1;

export default Group$1;
